==> haskell-dav-1.3.4-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-6dYLSVcNwL52N0MmDnPajh
key:                  DAV-1.3.4-6dYLSVcNwL52N0MmDnPajh
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  233c4dad85e5226d0204298c98c0fb03
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-8.10.1/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/DAV-1.3.4
hs-libraries:         HSDAV-1.3.4-6dYLSVcNwL52N0MmDnPajh
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-8AZUbBQpbxTCPQBw8ziEWX containers-0.6.2.1
    data-default-0.7.1.1-7DMDU8xt4e9EgbtAKNSosD exceptions-0.10.4
    http-client-0.7.0-ImPSPuNW1Y27y4PA1ax36I
    http-client-tls-0.3.5.3-7Yf4ROoTqY96CtTDiTAqUL
    http-types-0.12.3-1kde9KJAuu38Zmp5WnQ1fU
    lens-4.19.2-H3viRCem5kcJkuR7MpmLK5 mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-6dTWVQVkpndEzF8CB6LlYd
    transformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi
    utf8-string-1.0.1.1-L5P9SR8YxIu1NqwMrJwV7a
    xml-conduit-1.9.0.0-BVeMNOIfXU1BPloxzxpSbT
    xml-hamlet-0.5.0.1-2zlMwkjEEvt239IJcTRbT1

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.4-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DAV
version:              1.3.4
visibility:           public
id:                   DAV-1.3.4-OMpyZ58hcG1aoaNOJobVT
key:                  DAV-1.3.4-OMpyZ58hcG1aoaNOJobVT
license:              GPL-3.0-only
copyright:            Copyright (C) 2012-2020  Clint Adams
maintainer:           clint@debian.org
author:               Clint Adams
homepage:             http://floss.scru.org/hDAV
synopsis:             RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.

    In addition, there is an executable, hdav, which can be used for
    command-line operation.

category:             Web
abi:                  73f9f0ee561cf9e2aaed216471cdeae0
exposed:              True
exposed-modules:      Network.Protocol.HTTP.DAV
hidden-modules:       Network.Protocol.HTTP.DAV.TH
import-dirs:          /usr/lib/ghc-8.10.1/site-local/DAV-1.3.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/DAV-1.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/DAV-1.3.4
hs-libraries:         HSDAV-1.3.4-OMpyZ58hcG1aoaNOJobVT
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-4tL4tqWLN4BHWNmCD2HpmE containers-0.6.2.1
    data-default-0.7.1.1-9j14EdJuVkFLjYlD1tloIt exceptions-0.10.4
    http-client-0.7.1-Ebx7R4D92d92nOrdjjxerM
    http-client-tls-0.3.5.3-ExuY1AmhwHyIBvEGpEt4C0
    http-types-0.12.3-53LE6EPnjaYL88m7GHuG2H
    lens-4.19.2-CkbHRmHvgE2GNnqPKGf8fS mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.5.2-xMHQBtL7qH3C2eAD9DGp5
    transformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi
    utf8-string-1.0.1.1-L5P9SR8YxIu1NqwMrJwV7a
    xml-conduit-1.9.0.0-GHnC0xwHQJFV5kVdYmSnA
    xml-hamlet-0.5.0.1-AphgnpeBxuC2RXVAe00c4x

haddock-interfaces:   /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html:         /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
